function [cost,grad] = costFuncVec(data,beta)
%costFuncVec: returns the cost of a given predictor function and
%               a list of its correction factors
%
%   data: a matrix with k+1 columns; first k columns correspond to the  
%       input variables in order of their coefficients; k+1st is a vector   
%       of the output variables; rows correspond to observation numbers
%
%   beta: a vector containing the intercept and coefficient parameters of 
%       the predictor function in order
%
%   cost: the value of the cost function using the predictor function
%      defined
%
%   grad: a vector of the correction factors, ordered by their
%       corresponding parameter
%

X = [ones(length(data),1) data(:,1:size(data,2)-1)];
Y = data(:,size(data,2));
cost = (1/(2*length(Y)))*dot(X*beta'-Y,X*beta'-Y);
grad = (1/length(Y))*X'*(X*beta'-Y);

end

